/* test.c -- test data
 *
 * Copyright 2007 Dean Scarff
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License.  You
 * may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <stdlib.h>
#include <stdint.h>
#include <string.h>

#include "hope.h"

// For Ktest.+001+21102.private
const unsigned char test_modulus[] = {
	0xd0, 0x8f, 0x9c, 0x05, 0x41, 0x9e, 0xa7, 0x4e,
	0xf4, 0x2c, 0x77, 0xf3, 0xba, 0xd7, 0xc4, 0x60,
	0x1a, 0xcc, 0xcc, 0x4b, 0xc6, 0xe1, 0x85, 0xb0,
	0xcc, 0x54, 0x78, 0x4d, 0x30, 0xe1, 0xa2, 0xdb,
	0x73, 0x9d, 0x37, 0x8b, 0x56, 0x97, 0x72, 0x02,
	0x3e, 0x9f, 0xa9, 0xde, 0x9c, 0xf7, 0xc0, 0x62,
	0xa0, 0x3d, 0xe2, 0x53, 0x71, 0xde, 0xc0, 0xd7,
	0xb3, 0x8c, 0x3c, 0x38, 0x7c, 0x52, 0x6e, 0x67,
};

size_t test_modulus_size = sizeof(test_modulus);

uint16_t test_footprint = 0x526e;

// Query collected using nsupdate(8).
const unsigned char test_query[] = {
	0xb8, 0x37, 0x28, 0x00, 0x00, 0x01, 0x00, 0x00,
	0x00, 0x02, 0x00, 0x01, 0x06, 0x73, 0x63, 0x61,
	0x72, 0x66, 0x66, 0x02, 0x69, 0x64, 0x02, 0x61,
	0x75, 0x00, 0x00, 0x06, 0x00, 0x01, 0x04, 0x68,
	0x6f, 0x6d, 0x65, 0xc0, 0x0c, 0x00, 0x01, 0x00,
	0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0,
	0x1e, 0x00, 0x01, 0x00, 0x01, 0x00, 0x01, 0x51,
	0x80, 0x00, 0x04, 0x0d, 0x0d, 0x0d, 0x0d,
	// SIG(0):
	                                          0x00,
	0x00, 0x18, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00,
	0x00, 0x58, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x47, 0x53, 0xc4, 0x81, 0x47, 0x53,
	0xc2, 0x29, 0x52, 0x6e, 0x04, 0x74, 0x65, 0x73,
	0x74, 0x00
};

size_t test_query_size = sizeof(test_query);
size_t test_query_sig0_offset = 63;
size_t test_query_footprint_offset = 90;

const unsigned char test_signature[] = {
	0xc0, 0x71, 0x38, 0xd0, 0x31, 0xab, 0x02, 0x14,
	0x53, 0x12, 0xc0, 0x80, 0xa4, 0x4b, 0x29, 0x7c,
	0x3a, 0xa4, 0x1e, 0xb7, 0x15, 0x02, 0x1d, 0x8e,
	0x0d, 0x1a, 0xf1, 0x1c, 0x2b, 0x14, 0x20, 0x0c,
	0xce, 0x52, 0xf5, 0x73, 0x2a, 0xa4, 0xfc, 0x32,
	0xe2, 0x97, 0xcb, 0x92, 0x53, 0x21, 0x25, 0xbc,
	0x16, 0xfc, 0xd8, 0xd2, 0xf6, 0x3e, 0xf5, 0x06,
	0xc4, 0x84, 0xed, 0x12, 0x73, 0x8e, 0x02, 0xcf
};

const unsigned char test_hash_payload[] = {
	// SIG(0) rdata:
	0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
	0x47, 0x53, 0xc4, 0x81, 0x47, 0x53, 0xc2, 0x29,
	0x52, 0x6e, 0x04, 0x74, 0x65, 0x73, 0x74, 0x00,
	// original message:
	0xb8, 0x37, 0x28, 0x00, 0x00, 0x01, 0x00, 0x00,
	0x00, 0x02, 0x00, 0x00, 0x06, 0x73, 0x63, 0x61,
	0x72, 0x66, 0x66, 0x02, 0x69, 0x64, 0x02, 0x61,
	0x75, 0x00, 0x00, 0x06, 0x00, 0x01, 0x04, 0x68,
	0x6f, 0x6d, 0x65, 0xc0, 0x0c, 0x00, 0x01, 0x00,
	0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0,
	0x1e, 0x00, 0x01, 0x00, 0x01, 0x00, 0x01, 0x51,
	0x80, 0x00, 0x04, 0x0d, 0x0d, 0x0d, 0x0d
};

size_t test_hash_payload_size = sizeof(test_hash_payload);

const unsigned char test_digest[] = {
	0xc0, 0x63, 0xca, 0xbc, 0xc8, 0x2e, 0x4c, 0x35,
	0x02, 0x8a, 0xa5, 0x3d, 0xf1, 0x9d, 0x2a, 0x79
};

static const char keyfile_basename[] = "Ktest.+001+21102.private";

const char*
keyfile()
{
	const char *srcdir = getenv("srcdir");
	if (!srcdir)
		return "Ktest.+001+21102.private";

	size_t srcdirz = strlen(srcdir);
	char *f = xmalloc(1 + srcdirz +
	    sizeof(keyfile_basename));
	memcpy(f, srcdir, srcdirz);
	f[srcdirz] = '/';
	memcpy(f + srcdirz + 1, keyfile_basename,
	    sizeof(keyfile_basename));
	return f;
}
